==> haskell-hasql-pool-0.4.3-108-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-4ekVxoinxk02WTv2RoGXR5
key: hasql-pool-0.4.3-4ekVxoinxk02WTv2RoGXR5
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: 34ba3de76a105c93f92683844c11540b
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-4ekVxoinxk02WTv2RoGXR5
depends:
    resource-pool-0.2.3.2-5qcJWXaYqMe3bTNF5mDKzH
    hasql-1.1.1-1ab892PVg199oZiPWXHZhU time-1.8.0.2
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: resource-pool-0.2.3.2-5qcJWXaYqMe3bTNF5mDKzH=31bb64ba8f80a4d81164603db4d60d39
             hasql-1.1.1-1ab892PVg199oZiPWXHZhU=8d83c0d5e8e2e04436e9b5ead1cbe201
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.4.3-109-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-G1v1VrReZGwnFvaU43Hlq
key: hasql-pool-0.4.3-G1v1VrReZGwnFvaU43Hlq
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: 3654e0bcbd7b0b5d649de216e9113aee
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-G1v1VrReZGwnFvaU43Hlq
depends:
    resource-pool-0.2.3.2-DueoUqnCl4k2hDyKXj7xFa
    hasql-1.1.1-J7TMLxFh78k7e9ndaPkV2y time-1.8.0.2
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: resource-pool-0.2.3.2-DueoUqnCl4k2hDyKXj7xFa=59e7b3f4560186650f193f5ff70f93cd
             hasql-1.1.1-J7TMLxFh78k7e9ndaPkV2y=8670efe161258f8e610c9c2d775370d8
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
